<?php

namespace Omnipay\MOLPay\Message;

/**
 * MOLPay Purchase Request.
 *
 * ### Parameters
 *
 * * amount        [required] - Total amount to be paid
 * * card          [required] - Credit card details as an Omnipay CreditCard object
 * * description   [required] - Description of the purchase
 * * marchantId    [required] - Merchant ID provided by MOLPay
 * * transactionId [required] - Invoice or order number from merchant system
 * * verifyKey     [required] - Encrypted key generated by MOLPay
 */
class PurchaseRequest extends AbstractRequest
{
    /**
     * {@inheritdoc}
     */
    public function getData()
    {
        $this->validate('amount', 'card', 'description', 'merchantId', 'transactionId', 'verifyKey');
        $this->validateCreditCardDetails();

        if ($this->getPaymentMethod()) {
            $this->validatePaymentMethod();
        }

        $card = $this->getCard();

        return array(
            'amount' => $this->getAmount(),
            'bill_desc' => $this->getDescription(),
            'bill_email' => $card->getEmail(),
            'bill_mobile' => $card->getPhone(),
            'bill_name' => $card->getName(),
            'channel' => $this->getPaymentMethod(),
            'country' => $card->getCountry(),
            'currency' => $this->getCurrency(),
            'langcode' => $this->getLocale(),
            'orderid' => $this->getTransactionId(),
            'vcode' => $this->generateVCode(),
        );
    }

    /**
     * {@inheritdoc}
     */
    public function sendData($data)
    {
        return $this->response = new PurchaseResponse($this, $data);
    }

    /**
     * Generate vCode.
     *
     * @return string
     */
    protected function generateVCode()
    {
        $this->validate('amount', 'merchantId', 'transactionId', 'verifyKey');

        return md5($this->getAmount().$this->getMerchantId().$this->getTransactionId().$this->getVerifyKey());
    }
}
